@@ -4,23 +4,12 @@ from aoa.api.iterator_base_api import IteratorBaseApi
 
 
 class JobApi(IteratorBaseApi):
-
     path = "/api/jobs/"
 
-    def find_all(self, projection: str = None, page: int = None, size: int = None, sort: str = None):
-        """
-        returns all jobs
+    def find_by_archived(self, archived: bool = False, projection: str = None, page: int = None, size: int = None, sort: str = None):
+        raise NotImplemented("Archiving not supported for Jobs")
 
-        Parameters:
-           projection (str): projection type
-           page (int): page number
-           size (int): number of records in a page
-           sort (str): column name and sorting order
-           e.g. name?asc: sort name in ascending order, name?desc: sort name in descending order
-
-        Returns:
-            (dict): all jobs
-        """
+    def _get_header_params(self):
         header_vars = ['AOA-Project-ID', 'Accept']
         header_vals = [
             self.aoa_client.project_id,
@@ -29,46 +18,8 @@ class JobApi(IteratorBaseApi):
                 'application/hal+json',
                 'text/uri-list',
                 'application/x-spring-data-compact+json'])]
-        header_params = self.generate_params(header_vars, header_vals)
 
-        query_vars = ['projection', 'sort', 'page', 'size', 'sort']
-        query_vals = [projection, sort, page, size, sort]
-        query_params = self.generate_params(query_vars, query_vals)
-
-        return self.aoa_client.get_request(
-            self.path,
-            header_params,
-            query_params)
-
-    def find_by_id(self, job_id: str, projection: str = None):
-        """
-        returns a job
-
-        Parameters:
-           job_id (str): job id(uuid) to find
-           projection (str): projection type
-
-        Returns:
-            (dict): job
-        """
-        header_vars = ['AOA-Project-ID', 'Accept']
-        header_vals = [
-            self.aoa_client.project_id,
-            self.aoa_client.select_header_accept([
-                'application/json',
-                'application/hal+json',
-                'text/uri-list',
-                'application/x-spring-data-compact+json'])]
-        header_params = self.generate_params(header_vars, header_vals)
-
-        query_vars = ['projection']
-        query_vals = [projection]
-        query_params = self.generate_params(query_vars, query_vals)
-
-        return self.aoa_client.get_request(
-            self.path + job_id,
-            header_params,
-            query_params)
+        return self.generate_params(header_vars, header_vals)
 
     def find_job_events(self, job_id: str, projection: str = None):
         """
