@@ -1,13 +1,14 @@
-from aoa.model_utility.model_utility import ModelUtility
 import logging
 import json
+import yaml
 import os
+import uuid
 from jinja2 import Template
 
 
 class BaseModel(object):
 
-    def __init__(self, model_utility: ModelUtility):
+    def __init__(self, model_utility):
         self.model_utility = model_utility
 
     @staticmethod
@@ -31,6 +32,20 @@ class BaseModel(object):
 
         raise ValueError(model_ids)
 
+    def __get_model_varargs(self, model_id):
+        return {
+            "model_id": model_id,
+            "model_version": "cli",
+            "model_table": "AOA_MODELS_cli",
+            "project_id": self.__get_project_id(),
+            "job_id": str(uuid.uuid4())
+        }
+
+    def __get_project_id(self):
+        path = os.path.join(self.model_utility.base_path, ".aoa/config.yaml")
+        with open(path, "r") as handle:
+            return yaml.safe_load(handle)["project_id"]
+
     def __template_sql_script(self, filename, jinja_ctx):
         with open(filename) as f:
             template = Template(f.read())
@@ -55,7 +70,7 @@ class BaseModel(object):
                     else:
                         raise e
 
-    def __configure_pyspark(self, model_definition, model_artefacts_path, model_dir):
+    def __configure_pyspark(self, model_definition, model_artefacts_path, model_dir, mode):
         import findspark
         import os
         from zipfile import ZipFile
@@ -73,14 +88,28 @@ class BaseModel(object):
                         zip.write(full_file_path, zip_path)
 
         # read the spark submit resources for the model
-        if "resources" not in model_definition or "training" not in model_definition["resources"]:
-            raise Exception("pyspark models require a resources->training section in model.json")
+        try:
+            # current structure
+            if "automation" in model_definition and mode in model_definition["automation"]:
+                resources = model_definition["automation"][mode]["resources"]
+            # legacy 1
+            elif "resources" in model_definition:
+                resources = model_definition["resources"]["training"]
+            # legacy 2
+            else:
+                resources = model_definition["automation"]["resources"]["training"]
+        except KeyError as e:
+            raise Exception("pyspark models require an (automation)->resources->training section in model.json")
 
-        resources = model_definition["resources"]["training"]
         aoa_spark_conf = os.environ.get("AOA_SPARK_CONF", "--conf spark.aoa.modelPath={}".format(model_artefacts_path))
 
-        os.environ["PYSPARK_SUBMIT_ARGS"] = "--master {} {} --py-files {} {} pyspark-shell".format(
-            resources["master"], resources["args"], model_modules_fp.name, aoa_spark_conf)
+        # legacy support for master being specified as separate property. this should be moved to the args var now
+        specific_master_arg = ""
+        if "master" in resources:
+            specific_master_arg = "--master {}".format(resources["master"])
+
+        os.environ["PYSPARK_SUBMIT_ARGS"] = "{} {} --py-files {} {} pyspark-shell".format(
+            specific_master_arg, resources["args"], model_modules_fp.name, aoa_spark_conf)
 
         # SPARK_HOME should be set
         spark_home = findspark.find()
@@ -90,10 +119,15 @@ class BaseModel(object):
         self.logger.info("Using PYSPARK_SUBMIT_ARGS: {}".format(os.environ["PYSPARK_SUBMIT_ARGS"]))
         self.logger.info("Using AOA_SPARK_CONF: {}".format(os.environ.get("AOA_SPARK_CONF", "")))
 
-    def __get_engine(self, model_definition):
-        if "automation" in model_definition \
-                and "trainingEngine" in model_definition["automation"]:
-            return model_definition["automation"]["trainingEngine"]
+    def __get_engine(self, model_definition, mode):
+        if "automation" in model_definition:
+
+            if mode in model_definition["automation"] and "engine" in model_definition["automation"][mode]:
+                return model_definition["automation"][mode]["engine"]
+
+            # legacy
+            if "trainingEngine" in model_definition["automation"]:
+                return model_definition["automation"]["trainingEngine"]
 
         return model_definition["language"]
 
@@ -104,5 +138,6 @@ class BaseModel(object):
         with tempfile.NamedTemporaryFile(delete=False) as fp:
             fp.write(json.dumps(data_conf).encode())
 
-        cmd = self.model_utility.dir_path + "/run_model.R {} {} {} {}".format(model_id, mode, fp.name, base_path)
+        cmd = f"{self.model_utility.dir_path}/run_model.R {model_id} {self.__get_project_id()} {mode} {fp.name} {base_path}"
         subprocess.check_call(cmd, shell=True)
+
