@@ -45,8 +45,9 @@ class ModelUtility(object):
         self.__create_model_structure(model_path)
 
     @staticmethod
-    def clone_repository(url, path):
-        Repo.clone_from(url, path)
+    def clone_repository(url, path, branch: str = 'master'):
+        repo = Repo.clone_from(url, path)
+        repo.git.checkout(branch)
 
     def init_model_directory(self, path: str = None):
         logging.info('Creating model directory')
