@@ -89,14 +89,14 @@ class TrainModel(BaseModel):
 
     def __train_sql(self, model_dir, data_conf, model_conf, **kwargs):
         from teradataml.context.context import get_connection
-        from teradataml import create_context
+        from teradataml import create_context, remove_context
 
         self.logger.info("Starting training...")
 
-        create_context(host=data_conf["hostname"],
-                       username=os.environ["TD_USERNAME"],
-                       password=os.environ["TD_PASSWORD"],
-                       logmech=os.getenv("TD_LOGMECH", "TDNEGO"))
+        create_context(host=os.environ["AOA_CONN_HOST"],
+                   username=os.environ["AOA_CONN_USERNAME"],
+                   password=os.environ["AOA_CONN_PASSWORD"],
+                   logmech=os.getenv("AOA_CONN_LOG_MECH", "TDNEGO"))
 
         sql_file = model_dir + "/model_modules/training.sql"
         jinja_ctx = {
@@ -109,6 +109,8 @@ class TrainModel(BaseModel):
 
         self._BaseModel__execute_sql_script(get_connection(), sql_file, jinja_ctx)
 
+        remove_context()
+
         self.logger.info("Finished training")
 
         self.logger.info("Saved trained model")
